@@ -34,6 +34,7 @@
 #endif
 #include <canberra-gtk.h>
 
+#include "gcm-calibrate.h"
 #include "gcm-calibrate-argyll.h"
 #include "gcm-utils.h"
 #include "gcm-print.h"
@@ -109,121 +110,6 @@ gcm_calibrate_argyll_get_quality_arg (GcmCalibrateArgyll *calibrate_argyll)
 	return "-qm";
 }
 
-/**
- * gcm_calibrate_argyll_display_get_patches:
- **/
-static guint
-gcm_calibrate_argyll_display_get_patches (GcmCalibrateArgyll *calibrate_argyll)
-{
-	guint patches = 250;
-	GcmCalibratePrecision precision;
-
-	/* get kind */
-	g_object_get (calibrate_argyll,
-		      "precision", &precision,
-		      NULL);
-
-	if (precision == GCM_CALIBRATE_PRECISION_SHORT)
-		patches = 100;
-	else if (precision == GCM_CALIBRATE_PRECISION_NORMAL)
-		patches = 250;
-	else if (precision == GCM_CALIBRATE_PRECISION_LONG)
-		patches = 500;
-	return patches;
-}
-
-/**
- * gcm_calibrate_argyll_printer_get_patches:
- **/
-static guint
-gcm_calibrate_argyll_printer_get_patches (GcmCalibrateArgyll *calibrate_argyll)
-{
-	guint patches = 180;
-	CdSensorKind sensor_kind;
-	GcmCalibratePrecision precision;
-
-	/* we care about the kind */
-	g_object_get (calibrate_argyll,
-		      "sensor-kind", &sensor_kind,
-		      "precision", &precision,
-		      NULL);
-
-	if (precision == GCM_CALIBRATE_PRECISION_SHORT)
-		patches = 90;
-	else if (precision == GCM_CALIBRATE_PRECISION_NORMAL)
-		patches = 180;
-	else if (precision == GCM_CALIBRATE_PRECISION_LONG)
-		patches = 360;
-
-#ifdef USE_DOUBLE_DENSITY
-	/* using double density, so we can double the patch count */
-	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI ||
-	    sensor_kind == CD_SENSOR_KIND_SPECTRO_SCAN) {
-		patches *= 2;
-	}
-#endif
-
-	return patches;
-}
-
-#ifdef HAVE_VTE
-/**
- * gcm_calibrate_argyll_get_sensor_image_attach:
- **/
-static const gchar *
-gcm_calibrate_argyll_get_sensor_image_attach (GcmCalibrateArgyll *calibrate_argyll)
-{
-	CdSensorKind sensor_kind;
-
-	g_object_get (calibrate_argyll, "sensor-kind", &sensor_kind, NULL);
-	if (sensor_kind == CD_SENSOR_KIND_HUEY)
-		return "huey-attach.svg";
-	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI)
-		return "munki-attach.svg";
-	if (sensor_kind == CD_SENSOR_KIND_SPYDER)
-		return "spyder-attach.svg";
-	if (sensor_kind == CD_SENSOR_KIND_COLORIMTRE_HCFR)
-		return "hcfr-attach.svg";
-	if (sensor_kind == CD_SENSOR_KIND_I1_PRO)
-		return "i1-pro-attach.svg";
-	if (sensor_kind == CD_SENSOR_KIND_DTP94)
-		return "dtp94-attach.svg";
-#if CD_CHECK_VERSION(0,1,14)
-	if (sensor_kind == CD_SENSOR_KIND_I1_DISPLAY3)
-		return "i1-display3-attach.svg";
-#endif
-	return NULL;
-}
-
-/**
- * gcm_calibrate_argyll_get_sensor_image_calibrate:
- **/
-static const gchar *
-gcm_calibrate_argyll_get_sensor_image_calibrate (GcmCalibrateArgyll *calibrate_argyll)
-{
-	CdSensorKind sensor_kind;
-
-	g_object_get (calibrate_argyll, "sensor-kind", &sensor_kind, NULL);
-	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI)
-		return "munki-calibrate.svg";
-	return NULL;
-}
-
-/**
- * gcm_calibrate_argyll_get_sensor_image_screen:
- **/
-static const gchar *
-gcm_calibrate_argyll_get_sensor_image_screen (GcmCalibrateArgyll *calibrate_argyll)
-{
-	CdSensorKind sensor_kind;
-
-	g_object_get (calibrate_argyll, "sensor-kind", &sensor_kind, NULL);
-	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI)
-		return "munki-screen.svg";
-	return NULL;
-}
-#endif
-
 /**
  * gcm_calibrate_argyll_get_display:
  **/
@@ -357,9 +243,7 @@ gcm_calibrate_argyll_fork_command (GcmCalibrateArgyll *calibrate_argyll, gchar *
 {
 	gboolean ret = FALSE;
 #ifdef HAVE_VTE
-	const gchar *envp[] = { "ARGYLL_NOT_INTERACTIVE",
-				"ENABLE_COLORHUG=1",
-				NULL };
+	const gchar *envp[] = { "ARGYLL_NOT_INTERACTIVE", NULL };
 	const gchar *working_directory;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
 
@@ -588,108 +472,6 @@ out:
 	return ret;
 }
 
-/**
- * gcm_calibrate_argyll_display_generate_patches:
- **/
-static gboolean
-gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_argyll, GError **error)
-{
-	gboolean ret = TRUE;
-	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
-	gchar *command = NULL;
-	gchar **argv = NULL;
-	GPtrArray *array = NULL;
-	gchar *basename = NULL;
-	CdDeviceKind device_kind;
-
-	/* get shared data */
-	g_object_get (calibrate_argyll,
-		      "basename", &basename,
-		      "device-kind", &device_kind,
-		      NULL);
-
-	/* get correct name of the command */
-	command = gcm_calibrate_argyll_get_tool_filename ("targen", error);
-	if (command == NULL) {
-		ret = FALSE;
-		goto out;
-	}
-
-	/* TRANSLATORS: title, patches are specific colours used in calibration */
-	gcm_calibrate_set_title (GCM_CALIBRATE (calibrate_argyll),
-				 _("Generating the patches"));
-	/* TRANSLATORS: dialog message */
-	gcm_calibrate_set_message (GCM_CALIBRATE (calibrate_argyll),
-				   _("Generating the patches that will be measured with the color instrument."));
-
-	/* argument array */
-	array = g_ptr_array_new_with_free_func (g_free);
-
-	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
-	if (device_kind == CD_DEVICE_KIND_PRINTER) {
-		/* print RGB */
-		g_ptr_array_add (array, g_strdup ("-d2"));
-
-		/* Grey axis RGB steps */
-		g_ptr_array_add (array, g_strdup ("-g20"));
-	} else {
-		/* video RGB */
-		g_ptr_array_add (array, g_strdup ("-d3"));
-	}
-
-	/* get number of patches */
-	if (device_kind == CD_DEVICE_KIND_DISPLAY)
-		g_ptr_array_add (array, g_strdup_printf ("-f%i", gcm_calibrate_argyll_display_get_patches (calibrate_argyll)));
-	else if (device_kind == CD_DEVICE_KIND_PRINTER)
-		g_ptr_array_add (array, g_strdup_printf ("-f%i", gcm_calibrate_argyll_printer_get_patches (calibrate_argyll)));
-
-	g_ptr_array_add (array, g_strdup (basename));
-	argv = gcm_utils_ptr_array_to_strv (array);
-	gcm_calibrate_argyll_debug_argv (command, argv);
-
-	/* start up the command */
-	ret = gcm_calibrate_argyll_fork_command (calibrate_argyll, argv, error);
-	if (!ret)
-		goto out;
-
-	/* wait until finished */
-	g_main_loop_run (priv->loop);
-
-	/* get result */
-	if (priv->response == GTK_RESPONSE_CANCEL) {
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_USER_ABORT,
-				     "calibration was cancelled");
-		ret = FALSE;
-		goto out;
-	}
-#ifdef HAVE_VTE
-	if (priv->response == GTK_RESPONSE_REJECT) {
-		gchar *vte_text;
-		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
-		g_set_error (error,
-			     GCM_CALIBRATE_ERROR,
-			     GCM_CALIBRATE_ERROR_INTERNAL,
-			     "command failed to run successfully: %s", vte_text);
-		g_free (vte_text);
-		ret = FALSE;
-		goto out;
-	}
-#endif
-out:
-	if (array != NULL)
-		g_ptr_array_unref (array);
-	g_free (basename);
-	g_free (command);
-	g_strfreev (argv);
-	return ret;
-}
-
 /**
  * gcm_calibrate_argyll_display_draw_and_measure:
  **/
@@ -846,7 +628,7 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 	g_ptr_array_add (array, g_strdup_printf ("-D%s", description));
 	g_ptr_array_add (array, g_strdup_printf ("-C%s", copyright));
 	g_ptr_array_add (array, g_strdup (gcm_calibrate_argyll_get_quality_arg (calibrate_argyll)));
-	g_ptr_array_add (array, g_strdup ("-aS"));
+	g_ptr_array_add (array, g_strdup ("-as"));
 	g_ptr_array_add (array, g_strdup (basename));
 	argv = gcm_utils_ptr_array_to_strv (array);
 	gcm_calibrate_argyll_debug_argv (command, argv);
@@ -1378,21 +1160,25 @@ gcm_calibrate_argyll_display (GcmCalibrate *calibrate, CdDevice *device, CdSenso
 	if (!ret)
 		goto out;
 
-	/* step 2 */
-	ret = gcm_calibrate_argyll_display_generate_patches (calibrate_argyll, error);
-	if (!ret)
-		goto out;
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 30);
 
 	/* step 3 */
 	ret = gcm_calibrate_argyll_display_draw_and_measure (calibrate_argyll, error);
 	if (!ret)
 		goto out;
 
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 40);
+
 	/* step 4 */
 	ret = gcm_calibrate_argyll_display_generate_profile (calibrate_argyll, error);
 	if (!ret)
 		goto out;
 
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 80);
+
 	/* step 5 */
 	ret = gcm_calibrate_argyll_remove_temp_files (calibrate_argyll, error);
 	if (!ret)
@@ -1816,14 +1602,6 @@ gcm_calibrate_argyll_printer (GcmCalibrate *calibrate, CdDevice *device, CdSenso
 		      NULL);
 	working_path = gcm_calibrate_get_working_path (GCM_CALIBRATE (calibrate_argyll));
 
-	/* step 1 */
-	if (print_kind == GCM_CALIBRATE_PRINT_KIND_LOCAL ||
-	    print_kind == GCM_CALIBRATE_PRINT_KIND_GENERATE) {
-		ret = gcm_calibrate_argyll_display_generate_patches (calibrate_argyll, error);
-		if (!ret)
-			goto out;
-	}
-
 	/* print */
 	if (print_kind == GCM_CALIBRATE_PRINT_KIND_LOCAL) {
 		ret = gcm_print_with_render_callback (priv->print, window, (GcmPrintRenderCb) gcm_calibrate_argyll_render_cb, calibrate, error);
@@ -1867,6 +1645,9 @@ gcm_calibrate_argyll_printer (GcmCalibrate *calibrate, CdDevice *device, CdSenso
 
 	}
 
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 30);
+
 	/* we need to read the ti2 file to set the device used for calibration */
 	if (print_kind == GCM_CALIBRATE_PRINT_KIND_ANALYZE) {
 		filename = g_strdup_printf ("%s/%s.ti2", working_path, basename);
@@ -1883,11 +1664,17 @@ gcm_calibrate_argyll_printer (GcmCalibrate *calibrate, CdDevice *device, CdSenso
 			goto out;
 	}
 
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 60);
+
 	/* step 3 */
 	ret = gcm_calibrate_argyll_display_read_chart (calibrate_argyll, error);
 	if (!ret)
 		goto out;
 
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 80);
+
 	/* step 4 */
 	ret = gcm_calibrate_argyll_device_generate_profile (calibrate_argyll, error);
 	if (!ret)
@@ -2039,21 +1826,33 @@ gcm_calibrate_argyll_device (GcmCalibrate *calibrate, CdDevice *device, CdSensor
 	if (!ret)
 		goto out;
 
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 10);
+
 	/* step 2 */
 	ret = gcm_calibrate_argyll_device_measure (calibrate_argyll, error);
 	if (!ret)
 		goto out;
 
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 70);
+
 	/* step 3 */
 	ret = gcm_calibrate_argyll_device_generate_profile (calibrate_argyll, error);
 	if (!ret)
 		goto out;
 
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 80);
+
 	/* step 4 */
 	ret = gcm_calibrate_argyll_remove_temp_files (calibrate_argyll, error);
 	if (!ret)
 		goto out;
 
+	/* set progress */
+	gcm_calibrate_set_progress (calibrate, 90);
+
 	/* step 5 */
 	ret = gcm_calibrate_argyll_set_filename_result (calibrate_argyll, error);
 	if (!ret)
@@ -2063,9 +1862,6 @@ out:
 }
 
 #ifdef HAVE_VTE
-
-static void gcm_calibrate_argyll_flush_vte (GcmCalibrateArgyll *calibrate_argyll);
-
 /**
  * gcm_calibrate_argyll_exit_cb:
  **/
@@ -2075,9 +1871,6 @@ gcm_calibrate_argyll_exit_cb (VteTerminal *terminal, GcmCalibrateArgyll *calibra
 	gint exit_status;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
 
-	/* flush the VTE output */
-	gcm_calibrate_argyll_flush_vte (calibrate_argyll);
-
 	/* get the child exit status */
 	exit_status = vte_terminal_get_child_exit_status (terminal);
 	g_debug ("child exit-status is %i", exit_status);
@@ -2109,7 +1902,6 @@ gcm_calibrate_argyll_timeout_cb (GcmCalibrateArgyll *calibrate_argyll)
 static void
 gcm_calibrate_argyll_interaction_attach (GcmCalibrateArgyll *calibrate_argyll)
 {
-	const gchar *filename;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
 
 	/* different tools assume the device is not on the screen */
@@ -2122,40 +1914,14 @@ gcm_calibrate_argyll_interaction_attach (GcmCalibrateArgyll *calibrate_argyll)
 		goto out;
 	}
 
-	/* TRANSLATORS: title, instrument is a hardware color calibration sensor */
-	gcm_calibrate_set_title (GCM_CALIBRATE (calibrate_argyll),
-				 _("Please attach instrument"));
-
-	/* get the image, if we have one */
-	filename = gcm_calibrate_argyll_get_sensor_image_attach (calibrate_argyll);
-	gcm_calibrate_set_image (GCM_CALIBRATE (calibrate_argyll), filename);
-
-	/* different messages with or without image */
-	if (filename != NULL) {
-		/* TRANSLATORS: dialog message, ask user to attach device, and there's an example image */
-		gcm_calibrate_set_message (GCM_CALIBRATE (calibrate_argyll),
-				   _("Please attach the measuring instrument to the center of the screen on the gray square like the image below."));
-	} else {
-		/* TRANSLATORS: dialog message, ask user to attach device */
-		gcm_calibrate_set_message (GCM_CALIBRATE (calibrate_argyll),
-				   _("Please attach the measuring instrument to the center of the screen on the gray square."));
-	}
+	/* tell the user to attach the sensor */
+	gcm_calibrate_interaction_attach (GCM_CALIBRATE (calibrate_argyll));
 
 	/* block for a response */
 	g_debug ("blocking waiting for user input");
-	gcm_calibrate_interaction_required (GCM_CALIBRATE (calibrate_argyll), _("Continue"));
-
-	/* set state */
 	priv->argyllcms_ok = "\n";
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN,
 
-	/* play sound from the naming spec */
-	ca_context_play (ca_gtk_context_get (), 0,
-			 CA_PROP_EVENT_ID, "dialog-information",
-			 /* TRANSLATORS: this is the application name for libcanberra */
-			 CA_PROP_APPLICATION_NAME, _("GNOME Color Manager"),
-			 CA_PROP_EVENT_DESCRIPTION, "interaction required", NULL);
-
 	/* save as we know the device is on the screen now */
 	priv->already_on_window = TRUE;
 out:
@@ -2168,48 +1934,21 @@ out:
 static void
 gcm_calibrate_argyll_interaction_calibrate (GcmCalibrateArgyll *calibrate_argyll)
 {
-	const gchar *filename;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
 
-	/* TRANSLATORS: title, instrument is a hardware color calibration sensor */
-	gcm_calibrate_set_title (GCM_CALIBRATE (calibrate_argyll),
-				 _("Please configure instrument"));
+	/* standard dialog */
+	gcm_calibrate_interaction_calibrate (GCM_CALIBRATE (calibrate_argyll));
 
 	/* block for a response */
 	g_debug ("blocking waiting for user input");
 
-	/* get the image, if we have one */
-	filename = gcm_calibrate_argyll_get_sensor_image_calibrate (calibrate_argyll);
-	gcm_calibrate_set_image (GCM_CALIBRATE (calibrate_argyll), filename);
-
-	if (filename != NULL) {
-		/* TRANSLATORS: this is when the user has to change a setting on the sensor, and we're showing a picture */
-		gcm_calibrate_set_message (GCM_CALIBRATE (calibrate_argyll),
-				   _("Please set the measuring instrument to calibration mode like the image below."));
-	} else {
-		/* TRANSLATORS: this is when the user has to change a setting on the sensor */
-		gcm_calibrate_set_message (GCM_CALIBRATE (calibrate_argyll),
-				   _("Please set the measuring instrument to calibration mode."));
-	}
-
-
-	/* play sound from the naming spec */
-	ca_context_play (ca_gtk_context_get (), 0,
-			 CA_PROP_EVENT_ID, "dialog-information",
-			 /* TRANSLATORS: this is the application name for libcanberra */
-			 CA_PROP_APPLICATION_NAME, _("GNOME Color Manager"),
-			 CA_PROP_EVENT_DESCRIPTION, "setup calibration tool", NULL);
-
 	/* assume it's no longer on the window */
 	priv->already_on_window = FALSE;
 
 	/* assume it was done correctly */
 	priv->done_calibrate = TRUE;
-
-	/* set state */
 	priv->argyllcms_ok = "\n";
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN;
-	gcm_calibrate_interaction_required (GCM_CALIBRATE (calibrate_argyll), _("Continue"));
 }
 
 /**
@@ -2218,45 +1957,20 @@ gcm_calibrate_argyll_interaction_calibrate (GcmCalibrateArgyll *calibrate_argyll
 static void
 gcm_calibrate_argyll_interaction_surface (GcmCalibrateArgyll *calibrate_argyll)
 {
-	const gchar *filename;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
 
-	/* TRANSLATORS: title, instrument is a hardware color calibration sensor */
-	gcm_calibrate_set_title (GCM_CALIBRATE (calibrate_argyll),
-				 _("Please configure instrument"));
+	/* standard dialog */
+	gcm_calibrate_interaction_screen (GCM_CALIBRATE (calibrate_argyll));
 
 	/* block for a response */
 	g_debug ("blocking waiting for user input");
 
-	/* get the image, if we have one */
-	filename = gcm_calibrate_argyll_get_sensor_image_screen (calibrate_argyll);
-	gcm_calibrate_set_image (GCM_CALIBRATE (calibrate_argyll), filename);
-
-	if (filename != NULL) {
-		/* TRANSLATORS: this is when the user has to change a setting on the sensor, and we're showing a picture */
-		gcm_calibrate_set_message (GCM_CALIBRATE (calibrate_argyll),
-				   _("Please set the measuring instrument to screen mode like the image below."));
-	} else {
-		/* TRANSLATORS: this is when the user has to change a setting on the sensor */
-		gcm_calibrate_set_message (GCM_CALIBRATE (calibrate_argyll),
-				   _("Please set the measuring instrument to screen mode."));
-	}
-
-
-	/* play sound from the naming spec */
-	ca_context_play (ca_gtk_context_get (), 0,
-			 CA_PROP_EVENT_ID, "dialog-information",
-			 /* TRANSLATORS: this is the application name for libcanberra */
-			 CA_PROP_APPLICATION_NAME, _("GNOME Color Manager"),
-			 CA_PROP_EVENT_DESCRIPTION, "correct hardware state", NULL);
-
 	/* assume it's no longer on the window */
 	priv->already_on_window = FALSE;
 
 	/* set state */
 	priv->argyllcms_ok = "\n";
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN;
-	gcm_calibrate_interaction_required (GCM_CALIBRATE (calibrate_argyll), _("Continue"));
 }
 
 /**
@@ -2548,10 +2262,10 @@ gcm_calibrate_argyll_selection_func_cb (VteTerminal *terminal, glong column, glo
 }
 
 /**
- * gcm_calibrate_argyll_flush_vte:
+ * gcm_calibrate_argyll_cursor_moved_cb:
  **/
 static void
-gcm_calibrate_argyll_flush_vte (GcmCalibrateArgyll *calibrate_argyll)
+gcm_calibrate_argyll_cursor_moved_cb (VteTerminal *terminal, GcmCalibrateArgyll *calibrate_argyll)
 {
 	gchar *output;
 	gchar **split;
@@ -2560,7 +2274,6 @@ gcm_calibrate_argyll_flush_vte (GcmCalibrateArgyll *calibrate_argyll)
 	glong col;
 	gboolean ret;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
-	VteTerminal *terminal = VTE_TERMINAL (priv->terminal);
 
 	/* select the text we've got since last time */
 	vte_terminal_get_cursor_position (terminal, &col, &row);
@@ -2588,17 +2301,6 @@ gcm_calibrate_argyll_flush_vte (GcmCalibrateArgyll *calibrate_argyll)
 	g_free (output);
 	g_strfreev (split);
 }
-
-/**
- * gcm_calibrate_argyll_cursor_moved_cb:
- **/
-static void
-gcm_calibrate_argyll_cursor_moved_cb (VteTerminal *terminal,
-				      GcmCalibrateArgyll *calibrate_argyll)
-{
-	gcm_calibrate_argyll_flush_vte (calibrate_argyll);
-}
-
 #endif
 
 /**
