@@ -33,7 +33,6 @@
 
 #include "gcm-utils.h"
 #include "gcm-debug.h"
-#include "gcm-brightness.h"
 #include "gcm-calibrate.h"
 #include "gcm-calibrate-argyll.h"
 
@@ -66,13 +65,12 @@ typedef struct {
 	guint		 xid;
 	GtkWindow	*main_window;
 	GPtrArray	*pages;
-	GcmBrightness	*brightness;
-	guint		 old_brightness;
 	gboolean	 internal_lcd;
 	GtkWidget	*reference_preview;
 	GtkWidget	*action_title;
 	GtkWidget	*action_message;
 	GtkWidget	*action_image;
+	GtkWidget	*action_progress;
 	gboolean	 has_pending_interaction;
 	gboolean	 started_calibration;
 	GcmCalibratePage current_page;
@@ -192,89 +190,6 @@ gcm_calib_assistant_close_cb (GtkAssistant *assistant, GcmCalibratePriv *calib)
 	g_application_release (G_APPLICATION (calib->application));
 }
 
-/**
- * gcm_calib_device_inihibit:
- **/
-static void
-gcm_calib_device_inihibit (GcmCalibratePriv *calib)
-{
-	gboolean ret;
-	GError *error = NULL;
-
-	/* invalid */
-	if (calib->device == NULL)
-		return;
-
-	/* mark device to be profiled in colord */
-	ret = cd_device_profiling_inhibit_sync (calib->device,
-						calib->cancellable,
-						&error);
-	if (!ret) {
-		g_warning ("failed to inhibit device: %s",
-			   error->message);
-		g_clear_error (&error);
-	}
-
-	/* set the brightness to max */
-	if (calib->device_kind == CD_DEVICE_KIND_DISPLAY &&
-	    calib->internal_lcd) {
-		ret = gcm_brightness_get_percentage (calib->brightness,
-						     &calib->old_brightness,
-						     &error);
-		if (!ret) {
-			g_warning ("failed to get brightness: %s",
-				   error->message);
-			g_clear_error (&error);
-		}
-		ret = gcm_brightness_set_percentage (calib->brightness,
-						     100,
-						     &error);
-		if (!ret) {
-			g_warning ("failed to set brightness: %s",
-				   error->message);
-			g_error_free (error);
-		}
-	}
-}
-
-/**
- * gcm_calib_device_uninihibit:
- **/
-static void
-gcm_calib_device_uninihibit (GcmCalibratePriv *calib)
-{
-	gboolean ret;
-	GError *error = NULL;
-
-	/* invalid */
-	if (calib->device == NULL)
-		return;
-
-	/* mark device to be profiled in colord */
-	ret = cd_device_profiling_uninhibit_sync (calib->device,
-						  calib->cancellable,
-						  &error);
-	if (!ret) {
-		g_warning ("failed to uninhibit device: %s",
-			   error->message);
-		g_clear_error (&error);
-	}
-
-	/* reset the brightness to what it was before */
-	if (calib->device_kind == CD_DEVICE_KIND_DISPLAY &&
-	    calib->old_brightness != G_MAXUINT &&
-	    calib->internal_lcd) {
-		ret = gcm_brightness_set_percentage (calib->brightness,
-						     calib->old_brightness,
-						     &error);
-		if (!ret) {
-			g_warning ("failed to set brightness: %s",
-				   error->message);
-			g_error_free (error);
-		}
-	}
-}
-
 /**
  * gcm_calib_play_sound:
  **/
@@ -432,31 +347,10 @@ gcm_calib_start_idle_cb (gpointer user_data)
 
 	/* actuall do the action */
 	calib->started_calibration = TRUE;
-
-	switch (calib->device_kind) {
-	case CD_DEVICE_KIND_CAMERA:
-	case CD_DEVICE_KIND_WEBCAM:
-		ret = gcm_calibrate_device (calib->calibrate,
-					    calib->device,
-					    calib->main_window,
-					    &error);
-		break;
-	case CD_DEVICE_KIND_DISPLAY:
-		ret = gcm_calibrate_display (calib->calibrate,
-					     calib->device,
-					     calib->main_window,
-					     &error);
-		break;
-	case CD_DEVICE_KIND_PRINTER:
-		ret = gcm_calibrate_printer (calib->calibrate,
-					     calib->device,
-					     calib->main_window,
-					     &error);
-		break;
-	default:
-		g_assert_not_reached ();
-		break;
-	}
+	ret = gcm_calibrate_device (calib->calibrate,
+				    calib->device,
+				    calib->main_window,
+				    &error);
 	if (!ret) {
 		gcm_calibrate_set_title (calib->calibrate, _("Failed to calibrate"));
 		gcm_calibrate_set_message (calib->calibrate, error->message);
@@ -469,7 +363,6 @@ gcm_calib_start_idle_cb (gpointer user_data)
 		/* mark this box as the end */
 		vbox = gcm_calib_get_vbox_for_page (calib, GCM_CALIBRATE_PAGE_ACTION);
 		gtk_assistant_set_page_type (assistant, vbox, GTK_ASSISTANT_PAGE_SUMMARY);
-		gtk_assistant_set_page_complete (assistant, vbox, TRUE);
 		goto out;
 	}
 
@@ -550,7 +443,6 @@ gcm_calib_assistant_page_forward_cb (gint current_page, gpointer user_data)
 
 	/* continue calibration */
 	gcm_calibrate_interaction (calib->calibrate, GTK_RESPONSE_OK);
-	calib->has_pending_interaction = FALSE;
 
 	/* no longer allow forward */
 	vbox = gcm_calib_get_vbox_for_page (calib,
@@ -561,54 +453,6 @@ gcm_calib_assistant_page_forward_cb (gint current_page, gpointer user_data)
 	return current_page;
 }
 
-/**
- * gcm_calibrate_show_profile_location:
- **/
-static void
-gcm_calibrate_show_profile_location (void)
-{
-	gboolean ret;
-	gchar *command_line;
-	GError *error = NULL;
-
-	/* just hardcode nautilus to open the folder */
-	command_line = g_strdup_printf ("nautilus %s/%s",
-					g_get_user_data_dir (),
-					"icc");
-	ret = g_spawn_command_line_async (command_line, &error);
-	if (!ret) {
-		g_warning ("failed to show profile: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-out:
-	g_free (command_line);
-}
-
-/**
- * gcm_calibrate_is_livecd:
- **/
-static gboolean
-gcm_calibrate_is_livecd (void)
-{
-	gboolean ret;
-	gchar *data = NULL;
-	GError *error = NULL;
-
-	/* get the kernel commandline */
-	ret = g_file_get_contents ("/proc/cmdline", &data, NULL, &error);
-	if (!ret) {
-		g_warning ("failed to get kernel command line: %s",
-			   error->message);
-		g_error_free (error);
-		goto out;
-	}
-	ret = g_strstr_len (data, -1, "liveimg") != NULL;
-out:
-	g_free (data);
-	return ret;
-}
-
 /**
  * gcm_calib_assistant_prepare_cb:
  **/
@@ -617,25 +461,16 @@ gcm_calib_assistant_prepare_cb (GtkAssistant *assistant,
 				GtkWidget *page_widget,
 				GcmCalibratePriv *calib)
 {
-	gboolean ret;
 	calib->current_page = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (page_widget),
 								   "GcmCalibrateMain::Index"));
 	switch (calib->current_page) {
 	case GCM_CALIBRATE_PAGE_LAST:
-		gcm_calib_device_uninihibit (calib);
 		gcm_calib_play_sound (calib);
-
-		/* show the user the profile to copy off the live system */
-		ret = gcm_calibrate_is_livecd ();
-		if (ret)
-			gcm_calibrate_show_profile_location ();
 		break;
 	case GCM_CALIBRATE_PAGE_ACTION:
 		g_debug ("lights! camera! action!");
-		if (!calib->started_calibration) {
-			gcm_calib_device_inihibit (calib);
+		if (!calib->started_calibration)
 			g_idle_add (gcm_calib_start_idle_cb, calib);
-		}
 		break;
 	default:
 		break;
@@ -646,7 +481,6 @@ gcm_calib_assistant_prepare_cb (GtkAssistant *assistant,
 	    calib->started_calibration) {
 		gcm_calibrate_interaction (calib->calibrate,
 					   GTK_RESPONSE_CANCEL);
-		gcm_calib_device_uninihibit (calib);
 		calib->started_calibration = FALSE;
 	}
 
@@ -823,7 +657,6 @@ gcm_calib_setup_page_intro (GcmCalibratePriv *calib)
 static void
 gcm_calib_setup_page_summary (GcmCalibratePriv *calib)
 {
-	gboolean ret;
 	GtkWidget *vbox;
 	GtkWidget *content;
 	GtkWidget *image;
@@ -916,6 +749,10 @@ gcm_calib_setup_page_action (GcmCalibratePriv *calib)
 	gtk_image_set_from_icon_name (GTK_IMAGE (calib->action_image), "face-frown", GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (content), calib->action_image, FALSE, FALSE, 0);
 
+	/* add progress marker */
+	calib->action_progress = gtk_progress_bar_new ();
+	gtk_box_pack_start (GTK_BOX (content), calib->action_progress, FALSE, FALSE, 0);
+
 	/* add content widget */
 	gcm_calibrate_set_content_widget (calib->calibrate, vbox);
 
@@ -1240,9 +1077,6 @@ gcm_calib_reference_kind_combobox_cb (GtkComboBox *combo_box,
 
 	/* not sorted so we can just use the index */
 	reference_kind = gtk_combo_box_get_active (GTK_COMBO_BOX (combo_box));
-	g_object_set (calib->calibrate,
-		      "reference-kind", reference_kind,
-		      NULL);
 	filename = gcm_calib_reference_kind_to_image_filename (reference_kind);
 
 	/* fallback */
@@ -1855,48 +1689,6 @@ gcm_calib_setup_page_failure (GcmCalibratePriv *calib)
 	gtk_widget_show_all (vbox);
 }
 
-/**
- * gcm_calib_got_sensor:
- **/
-static void
-gcm_calib_got_sensor (GcmCalibratePriv *calib, CdSensor *sensor)
-{
-	gboolean is_photospectrometer = FALSE;
-	gboolean ret;
-	GError *error = NULL;
-	GtkWidget *vbox;
-
-	/* connect to sensor */
-	ret = cd_sensor_connect_sync (sensor, NULL, &error);
-	if (!ret) {
-		g_warning ("failed to connect to sensor: %s",
-			   error->message);
-		g_error_free (error);
-		goto out;
-	}
-	calib->sensor = g_object_ref (sensor);
-	gcm_calibrate_set_sensor (calib->calibrate, sensor);
-
-	/* hide the prompt for the user to insert a sensor */
-	vbox = gcm_calib_get_vbox_for_page (calib,
-					    GCM_CALIBRATE_PAGE_SENSOR);
-	gtk_widget_hide (vbox);
-
-	/* if the device is a simple colorimeter, hide the temperature
-	 * chooser. Only expensive accurate spectrophotometers are
-	 * accurate enough to do a good job without a color cast */
-	if (cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_I1_PRO ||
-	    cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_COLOR_MUNKI ||
-	    cd_sensor_get_kind (sensor) == CD_SENSOR_KIND_I1_DISPLAY3) {
-		is_photospectrometer = TRUE;
-	}
-	vbox = gcm_calib_get_vbox_for_page (calib,
-					    GCM_CALIBRATE_PAGE_DISPLAY_TEMPERATURE);
-	gtk_widget_set_visible (vbox, is_photospectrometer);
-out:
-	return;
-}
-
 /**
  * gcm_calib_get_sensors_cb:
  **/
@@ -1906,10 +1698,11 @@ gcm_calib_get_sensors_cb (GObject *object,
 			  gpointer user_data)
 {
 	CdClient *client = CD_CLIENT (object);
-	CdSensor *sensor_tmp;
 	GcmCalibratePriv *calib = (GcmCalibratePriv *) user_data;
 	GError *error = NULL;
 	GPtrArray *sensors;
+	GtkWidget *vbox;
+	gboolean ret;
 
 	/* get the result */
 	sensors = cd_client_get_sensors_finish (client, res, &error);
@@ -1920,10 +1713,22 @@ gcm_calib_get_sensors_cb (GObject *object,
 		goto out;
 	}
 
-	/* we've got a sensor */
-	if (sensors->len != 0) {
-		sensor_tmp = g_ptr_array_index (sensors, 0);
-		gcm_calib_got_sensor (calib, sensor_tmp);
+	/* hide the sensors screen */
+	if (sensors->len > 0) {
+		calib->sensor = g_object_ref (g_ptr_array_index (sensors, 0));
+
+		ret = cd_sensor_connect_sync (calib->sensor, NULL, &error);
+		if (!ret) {
+			g_warning ("failed to connect to sensor: %s",
+				   error->message);
+			g_error_free (error);
+			goto out;
+		}
+
+		gcm_calibrate_set_sensor (calib->calibrate, calib->sensor);
+		vbox = gcm_calib_get_vbox_for_page (calib,
+						    GCM_CALIBRATE_PAGE_SENSOR);
+		gtk_widget_hide (vbox);
 	}
 out:
 	if (sensors != NULL)
@@ -2002,9 +1807,13 @@ gcm_calib_add_pages (GcmCalibratePriv *calib)
 static void
 gcm_calib_sensor_added_cb (CdClient *client, CdSensor *sensor, GcmCalibratePriv *calib)
 {
+	GtkWidget *vbox;
+
 	g_debug ("sensor inserted");
-	gcm_calib_got_sensor (calib, sensor);
-	gtk_assistant_next_page (GTK_ASSISTANT (calib->main_window));
+	calib->sensor = g_object_ref (sensor);
+	vbox = gcm_calib_get_vbox_for_page (calib,
+					    GCM_CALIBRATE_PAGE_SENSOR);
+	gtk_widget_hide (vbox);
 }
 
 /**
@@ -2171,6 +1980,15 @@ gcm_calib_message_changed_cb (GcmCalibrate *calibrate,
 	gtk_label_set_label (GTK_LABEL (calib->action_message), title);
 }
 
+static void
+gcm_calib_progress_changed_cb (GcmCalibrate *calibrate,
+			       guint percentage,
+			       GcmCalibratePriv *calib)
+{
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (calib->action_progress),
+				       percentage / 100.0f);
+}
+
 static void
 gcm_calib_image_changed_cb (GcmCalibrate *calibrate,
 			    const gchar *filename,
@@ -2251,9 +2069,10 @@ main (int argc, char **argv)
 	calib->pages = g_ptr_array_new ();
 	calib->xid = xid;
 	calib->device_id = device_id;
-	calib->old_brightness = G_MAXUINT;
-	calib->brightness = gcm_brightness_new ();
 	calib->calibrate = gcm_calibrate_argyll_new ();
+	g_object_set (calib->calibrate,
+		      "precision", GCM_CALIBRATE_PRECISION_LONG,
+		      NULL);
 	calib->device_kind = CD_DEVICE_KIND_UNKNOWN;
 	g_signal_connect (calib->calibrate, "title-changed",
 			  G_CALLBACK (gcm_calib_title_changed_cb), calib);
@@ -2261,6 +2080,8 @@ main (int argc, char **argv)
 			  G_CALLBACK (gcm_calib_message_changed_cb), calib);
 	g_signal_connect (calib->calibrate, "image-changed",
 			  G_CALLBACK (gcm_calib_image_changed_cb), calib);
+	g_signal_connect (calib->calibrate, "progress-changed",
+			  G_CALLBACK (gcm_calib_progress_changed_cb), calib);
 	g_signal_connect (calib->calibrate, "interaction-required",
 			  G_CALLBACK (gcm_calib_interaction_required_cb), calib);
 
@@ -2282,7 +2103,6 @@ main (int argc, char **argv)
 
 	g_ptr_array_unref (calib->pages);
 	g_object_unref (calib->application);
-	g_object_unref (calib->brightness);
 	g_object_unref (calib->calibrate);
 	if (calib->client != NULL)
 		g_object_unref (calib->client);
